Struct ext_sort::sort::ExternalSorterBuilder[][src]

pub struct ExternalSorterBuilder<T, E, B = LimitedBufferBuilder, C = RmpExternalChunk<T>> where
    T: Ord + Send,
    E: Error,
    B: ChunkBufferBuilder<T>,
    C: ExternalChunk<T>, 
{ /* fields omitted */ }
External sorter builder. Provides methods for ExternalSorter initialization.

Implementations

Creates an instance of a builder with default parameters.

Builds an ExternalSorter instance using provided configuration.

Sets number of threads to be used to sort data in parallel.

Sets directory to be used to store temporary data.

Sets buffer builder.

Sets chunk read/write buffer size.