Struct ext_sort::sort::ExternalSorterBuilder [−][src]
pub struct ExternalSorterBuilder<T, E, B = LimitedBufferBuilder, C = RmpExternalChunk<T>> where
T: Ord + Send,
E: Error,
B: ChunkBufferBuilder<T>,
C: ExternalChunk<T>, { /* fields omitted */ }Expand description
External sorter builder. Provides methods for ExternalSorter initialization.
Implementations
impl<T, E, B, C> ExternalSorterBuilder<T, E, B, C> where
T: Ord + Send,
E: Error,
B: ChunkBufferBuilder<T>,
C: ExternalChunk<T>,
impl<T, E, B, C> ExternalSorterBuilder<T, E, B, C> where
T: Ord + Send,
E: Error,
B: ChunkBufferBuilder<T>,
C: ExternalChunk<T>,
pub fn build(
self
) -> Result<ExternalSorter<T, E, B, C>, SortError<C::SerializationError, C::DeserializationError, E>>
pub fn build(
self
) -> Result<ExternalSorter<T, E, B, C>, SortError<C::SerializationError, C::DeserializationError, E>>
Builds an ExternalSorter instance using provided configuration.
Sets number of threads to be used to sort data in parallel.
Sets directory to be used to store temporary data.
Sets buffer builder.
Sets chunk read/write buffer size.